<template>
  <div class="fixed inset-0 bg-gray-600 bg-opacity-50 overflow-y-auto h-full w-full z-50" v-if="showModal">
    <div class="relative top-20 mx-auto p-5 border w-full max-w-2xl shadow-lg rounded-md bg-white">
      <div class="flex justify-between items-center mb-4">
        <h3 class="text-lg font-medium">{{ assistantForm.id ? 'Edit AI Assistant' : 'Add AI Assistant' }}</h3>
        <button @click="$emit('close')" class="text-gray-500 hover:text-gray-700">
          <svg class="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12" />
          </svg>
        </button>
      </div>
      
      <form @submit.prevent="$emit('saveAssistant')" class="space-y-4">
        <div>
          <label class="block text-sm font-medium text-gray-700">Assistant Name</label>
          <input type="text" v-model="assistantForm.name" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm">
        </div>

        <div>
          <label class="block text-sm font-medium text-gray-700">Description</label>
          <input type="text" v-model="assistantForm.description" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm">
        </div>

        <div>
          <label class="block text-sm font-medium text-gray-700">Knowledge Base</label>
          <select v-model="assistantForm.knowledge_base_id" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm">
            <option :value="null">None</option>
            <option v-for="kb in knowledgeBases" :key="kb.id" :value="kb.id">{{ kb.title }}</option>
          </select>
        </div>

        <div>
          <label class="block text-sm font-medium text-gray-700">Classification Purpose</label>
          <div class="flex items-center space-x-4 mt-1">
            <label class="inline-flex items-center">
              <input type="radio" v-model="assistantForm.classification_purpose" :value="true" class="form-radio text-indigo-600">
              <span class="ml-2">Yes</span>
            </label>
            <label class="inline-flex items-center">
              <input type="radio" v-model="assistantForm.classification_purpose" :value="false" class="form-radio text-indigo-600">
              <span class="ml-2">No</span>
            </label>
          </div>
        </div>

        <div>
          <label class="block text-sm font-medium text-gray-700">Status</label>
          <div class="flex items-center space-x-4 mt-1">
            <label class="inline-flex items-center">
              <input type="radio" v-model="assistantForm.enabled" :value="true" class="form-radio text-indigo-600">
              <span class="ml-2">Enabled</span>
            </label>
            <label class="inline-flex items-center">
              <input type="radio" v-model="assistantForm.enabled" :value="false" class="form-radio text-indigo-600">
              <span class="ml-2">Disabled</span>
            </label>
          </div>
        </div>

        <!-- Advanced Settings Section -->
        <div class="border-t pt-4 mt-4">
          <h4 class="text-md font-medium mb-2">Advanced Settings</h4>
          
          <div>
            <label class="block text-sm font-medium text-gray-700">Pre-Prompt</label>
            <textarea v-model="settings.prePrompt" rows="3" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm"></textarea>
          </div>
          
          <div class="grid grid-cols-2 gap-4 mt-4">
            <div>
              <label class="block text-sm font-medium text-gray-700">Max Tokens</label>
              <input type="number" v-model="settings.maxTokens" min="1" max="4000" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm">
            </div>
            
            <div>
              <label class="block text-sm font-medium text-gray-700">Temperature</label>
              <input type="number" v-model="settings.temperature" min="0" max="1" step="0.1" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm">
            </div>
          </div>
          
          <div class="mt-4">
            <label class="block text-sm font-medium text-gray-700">Memory</label>
            <div class="flex items-center mt-1">
              <label class="inline-flex items-center">
                <input type="checkbox" v-model="settings.memoryEnabled" class="form-checkbox text-indigo-600">
                <span class="ml-2">Enable Memory</span>
              </label>
            </div>
          </div>
          
          <div v-if="settings.memoryEnabled" class="mt-2">
            <label class="block text-sm font-medium text-gray-700">Memory Size</label>
            <input type="number" v-model="settings.memorySize" min="1" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-indigo-500 focus:ring-indigo-500 sm:text-sm">
          </div>
        </div>

        <div class="flex justify-end space-x-3 mt-6">
          <button type="button" @click="$emit('close')" class="px-4 py-2 border border-gray-300 rounded-md shadow-sm text-sm font-medium text-gray-700 bg-white hover:bg-gray-50">
            Cancel
          </button>
          <button type="submit" class="px-4 py-2 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-green-700 hover:bg-green-800">
            {{ assistantForm.id ? 'Update' : 'Create' }}
          </button>
        </div>
      </form>
    </div>
  </div>
</template>

<script>
import { computed, ref, watch } from 'vue';

export default {
  props: {
    showModal: {
      type: Boolean,
      required: true
    },
    assistantForm: {
      type: Object,
      required: true
    },
    knowledgeBases: {
      type: Array,
      default: () => []
    }
  },
  
  emits: ['close', 'saveAssistant'],
  
  setup(props) {
    // Parse settings from JSON string
    const settings = ref({
      classification: '',
      prePrompt: '',
      maxTokens: 2000,
      temperature: 0.7,
      memoryEnabled: true,
      memorySize: 10
    });
    
    // Watch for changes in assistantForm.settings and update local settings
    watch(() => props.assistantForm.settings, (newSettings) => {
      try {
        const parsedSettings = JSON.parse(newSettings);
        settings.value = {
          classification: parsedSettings.classification || '',
          prePrompt: parsedSettings.prePrompt || '',
          maxTokens: parsedSettings.maxTokens || 2000,
          temperature: parsedSettings.temperature || 0.7,
          memoryEnabled: parsedSettings.memoryEnabled || true,
          memorySize: parsedSettings.memorySize || 10
        };
      } catch (e) {
        console.error('Error parsing settings:', e);
      }
    }, { immediate: true });
    
    // Update assistantForm.settings when local settings change
    watch(settings, (newSettings) => {
      props.assistantForm.settings = JSON.stringify(newSettings);
    }, { deep: true });
    
    return {
      settings
    };
  }
};
</script>
